==> corestuff-2.7.0.tar.gz: corestuff-v2.7.0/home/pagehome.h <==
/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#pragma once

#include <QWidget>

#include "global.h"

class QListWidgetItem;

namespace Ui {
class pagehome;
}

class pagehome : public QWidget
{
    Q_OBJECT

public:
    explicit pagehome(QWidget *parent = nullptr);
    ~pagehome();

private:
    Ui::pagehome *ui;
    int           widgetViewWidth;
    QSize         iconViewIconSize;
    bool          touch;
    QStringList   selectedPlugins, favouriteApps;

    void startSetup();
    void loadSettings();
    void setupWidgetView();
    void setupAppsView();
    void updateTime();
    void openSelectedApp(QListWidgetItem *item);
};

==> corestuff-2.9.0.tar.gz: corestuff-v2.9.0/home/pagehome.h <==
/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#pragma once

#include <QWidget>
#include <QScrollArea>
#include <QScrollBar>
#include <QBasicTimer>

#include "global.h"


class QListWidgetItem;

namespace Ui {
class pagehome;
}

class pagehome : public QWidget
{
    Q_OBJECT

public:
    explicit pagehome(QWidget *parent = nullptr);
    ~pagehome();

private:
    Ui::pagehome    *ui;
    QStringList      selectedPlugins;
    bool             touch, desktop, tabletMode;
    QPoint           mStart;
    QBasicTimer      moveTimer;
    bool             mScrolled = false;

    void loadSettings();
    void setupWidgetView(QRect geometry);
    void updateTime();
    void startSetup();
};
